# Examples

This folder contains examples of how to use `mlflow-sweep` to perform hyperparameter tuning with MLflow for different
machine learning frameworks.

* dummy folder: Contains a simple example of example usage
* sklearn folder: Contains an example of hyperparameter tuning with scikit-learn
* mlflow project folder: Contains an example of how to integrate `mlflow-sweep` with an MLflow project
